@@ -319,8 +319,6 @@ class mtse:
                 train_batch, label = train_batch.to(self.device), label.to(self.device) 
                 batch_len  = train_batch.shape[0]
                 out = self.ts_encoder(train_batch[:, :, :self.n_ts*2], train_batch[:, :, -1])  
-                print(out)
-                print(out.shape)                  
                 loss = criterion(out, label)
                 train_loss += loss.item() * batch_len
                 train_n += batch_len
